"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.isBuildInfo = exports.knownIstancesList = exports.trustedProtocolRegExp = exports.jsonOrJsonc = exports.objectsAreSameType = exports.discordFavicons = exports.packageJson = exports.checkPackageJsonComplete = exports.isPackageJsonComplete = exports.wLog = void 0;
const fs_1 = require("fs");
const path_1 = require("path");
const semver_1 = require("semver");
function wLog(msg) {
    console.log("%c[WebCord]", 'color: #69A9C1', msg);
}
exports.wLog = wLog;
function isEmail(email) {
    return (email?.match(/^[a-z0-9!#$%&'*+/=?^_`{|}~-][a-z0-9!#$%&'*+/=?^_`{|}~\-.]*@[a-z0-9!#$%&'*+/=?^_`{|}~-][a-z0-9!#$%&'*+/=?^_`{|}~\-.]*\.[a-z]+$/) !== null);
}
function isPerson(variable) {
    if (typeof variable !== 'string' && typeof variable !== 'object')
        return false;
    if (typeof variable === 'object') {
        if (typeof variable.name !== 'string')
            return false;
        if (variable.email !== undefined && typeof variable.email !== 'string')
            return false;
        else if (typeof variable.email === 'string' && !isEmail(variable.email))
            return false;
        if (variable.url !== undefined && typeof variable.url !== 'string')
            return false;
    }
    if (typeof variable === 'string') {
        return (variable.split(/\[.*\]|<.*>/).length < 2 ||
            (variable.split(/\[.*\]|<.*>/).length == 2 &&
                variable.split(/\[.*\]|<.*>/)[1] === '')) && (!variable.match(/<.*>/) ||
            isEmail(variable.replace(/.*<(.*)>.*/, '$1')));
    }
    return true;
}
function isPackageJsonComplete(object) {
    return (checkPackageJsonComplete(object) === "");
}
exports.isPackageJsonComplete = isPackageJsonComplete;
function checkPackageJsonComplete(object) {
    if (typeof object.contributors === "object")
        for (const key of object.contributors)
            if (!isPerson(key))
                return "Contributors field is of invalid type.";
    if (!isPerson(object.author))
        return "Author field is of invalid type.";
    for (const stringKey of ['name', 'homepage'])
        if (typeof (object[stringKey]) !== 'string')
            return "'" + stringKey + "' is not assignable to type 'string'.";
    if (typeof object.repository !== "string" && typeof object.repository !== "object")
        return "Repository field is neither of type 'string' nor 'object'.";
    for (const stringKey of ['type', 'url']) {
        const repository = object.repository;
        if (typeof (repository) === "object" && typeof (repository[stringKey]) !== "string")
            return "Repository object does not contain a '" + stringKey + "' property.";
    }
    if (object.name.match(/^(?:@[a-z0-9-*~][a-z0-9-*._~]*\/)?[a-z0-9-~][a-z0-9-._~]*$/) === null)
        return "'" + object.name + "' is not a valid Node.js package name.";
    if (typeof object.version === 'string') {
        if ((0, semver_1.parse)(object.version) === null)
            return "Version " + object.version + " can't be parsed to 'semver'.";
    }
    else {
        return "Version property is not assignable to type 'string'!";
    }
    return "";
}
exports.checkPackageJsonComplete = checkPackageJsonComplete;
function getPackageJsonProperties() {
    const packageJSON = JSON.parse((0, fs_1.readFileSync)((0, path_1.resolve)(__dirname, "../../package.json")).toString());
    if (!isPackageJsonComplete(packageJSON))
        throw new TypeError(checkPackageJsonComplete("While parsing `package.json`: " + packageJSON));
    return {
        name: packageJSON.name,
        author: packageJSON.author,
        contributors: packageJSON.contributors,
        homepage: packageJSON.homepage,
        repository: packageJSON.repository
    };
}
exports.packageJson = getPackageJsonProperties();
exports.discordFavicons = {
    default: '25522cef7e234ab001bbbc85c7a3f477b996e20b'
};
function objectsAreSameType(object1, object2) {
    if (!(object1 instanceof Object && object2 instanceof Object))
        return false;
    if (JSON.stringify(object1) === JSON.stringify(object2))
        return true;
    const obj1 = object1, obj2 = object2;
    const keyArray1 = [], keyArray2 = [];
    for (const key1 in obj1)
        keyArray1.push(key1);
    for (const key2 in obj2)
        keyArray2.push(key2);
    if (keyArray1.sort().toString() !== keyArray2.sort().toString())
        return false;
    for (const key of keyArray1) {
        if (Object.prototype.hasOwnProperty.call(obj1, key) && Object.prototype.hasOwnProperty.call(obj2, key))
            if (Array.isArray(obj1[key]) && Array.isArray(obj2[key])) {
                break;
            }
            else if (obj1[key] instanceof Object && obj2[key] instanceof Object) {
                const test = objectsAreSameType(obj1[key], obj2[key]);
                if (!test)
                    return false;
            }
            else if ((typeof (obj1[key]) !== typeof (obj2[key]))) {
                return false;
            }
    }
    return true;
}
exports.objectsAreSameType = objectsAreSameType;
function jsonOrJsonc(fileNoExtension) {
    if ((0, fs_1.existsSync)(fileNoExtension + '.jsonc'))
        return fileNoExtension + '.jsonc';
    else
        return fileNoExtension + '.json';
}
exports.jsonOrJsonc = jsonOrJsonc;
exports.trustedProtocolRegExp = /^(https:|mailto:|tel:|sms:)$/;
exports.knownIstancesList = [
    ["Discord", new URL("https://discord.com/app")],
    ["Fosscord", new URL("https://dev.fosscord.com/app")]
];
function isBuildInfo(object) {
    if (!(object instanceof Object))
        return false;
    if (!Object.prototype.hasOwnProperty.call(object, 'type'))
        return false;
    switch (object.type) {
        case 'release':
        case 'devel':
            break;
        default:
            return false;
    }
    if (Object.prototype.hasOwnProperty.call(object, 'commit'))
        if (!(typeof object.commit === 'string'))
            return false;
    const features = ['updateNotifications'];
    if (Object.prototype.hasOwnProperty.call(object, 'features'))
        if (!(object.features instanceof Object))
            return false;
        else
            for (const property of features)
                if (Object.prototype.hasOwnProperty.call(object.features, property))
                    if (typeof object.features[property] !== "boolean")
                        return false;
    return true;
}
exports.isBuildInfo = isBuildInfo;
