"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
Promise.resolve().then(() => require('source-map-support')).then(sMap => sMap.install());
Promise.resolve().then(() => require('./modules/error')).then(eHand => eHand.default());
console.debug = function (message, ...optionalParams) {
    Promise.resolve().then(() => require('electron')).then(e => e.app.commandLine.hasSwitch).then(hasSwitch => {
        Promise.resolve().then(() => require('colors/safe')).then(colors => {
            if (hasSwitch('verbose') || hasSwitch('v'))
                console.log(colors.gray(message), ...optionalParams);
        });
    });
};
{
    const stdErr = console.error;
    const stdWarn = console.warn;
    console.error = function (message, ...optionalParams) {
        Promise.resolve().then(() => require('colors/safe')).then(colors => {
            stdErr(colors.red(message), ...optionalParams);
        });
    };
    console.warn = function (message, ...optionalParams) {
        Promise.resolve().then(() => require('colors/safe')).then(colors => {
            stdWarn(colors.yellow(message), ...optionalParams);
        });
    };
}
const electron_1 = require("electron");
const fs_1 = require("fs");
const global_1 = require("./global");
const update_1 = require("./main/modules/update");
const l10n_1 = require("./modules/l10n");
const main_1 = require("./main/windows/main");
const about_1 = require("./main/windows/about");
const config_1 = require("./main/modules/config");
const colors = require("colors/safe");
const path_1 = require("path");
let startHidden = false;
let overwriteMain;
{
    const renderLine = (parameter, description, length) => {
        const spaceBetween = (length ?? 30) - parameter.length;
        return '  ' + colors.green(parameter) + ' '.repeat(spaceBetween) + colors.gray(description) + '\n';
    };
    const { hasSwitch, getSwitchValue } = electron_1.app.commandLine;
    if (hasSwitch('help') || hasSwitch('h')) {
        console.log("\n " + colors.bold(colors.blue(electron_1.app.getName())) +
            " – Privacy focused Discord client made with " + colors.bold(colors.white(colors.bgBlue("TypeScript"))) + " and " + colors.bold(colors.bgBlack(colors.cyan("Electron"))) + '.\n\n' +
            " " + colors.underline("Usage:") + " " + colors.red(process.argv0) + colors.green(" [option]\n\n") +
            " " + colors.underline("Options:") + "\n" +
            renderLine('--version  -V', 'Show current application version.') +
            renderLine('--start-minimized  -m', 'Hide application at first run.') +
            renderLine('--export-l10n' + '=' + colors.yellow('{dir}'), '          Export currently loaded translation files from') +
            " ".repeat(32) + colors.gray("the application to the " + colors.yellow('{dir}') + " directory.\n") +
            renderLine('--verbose  -v', "Show debug messages."));
        electron_1.app.exit();
    }
    if (hasSwitch('version') || hasSwitch('V')) {
        console.log(electron_1.app.getName() + ' v' + electron_1.app.getVersion());
        electron_1.app.exit();
    }
    if (hasSwitch('start-minimized') || hasSwitch('m'))
        startHidden = true;
    if (hasSwitch('export-l10n')) {
        overwriteMain = () => {
            const locale = new l10n_1.default;
            const directory = getSwitchValue('export-l10n');
            const filePromise = [];
            for (const file in locale)
                filePromise.push(fs_1.promises.writeFile((0, path_1.resolve)(directory, file + '.json'), JSON.stringify(locale[file], null, 2)));
            Promise.all(filePromise).then(() => {
                console.log("\n🎉️ Successfully exported localization files to \n" +
                    "   '" + directory + "'!\n");
                electron_1.app.quit();
            }).catch((err) => {
                console.error('\n⛔️ ' + colors.red(colors.bold(err.code || err.name)) + ' ' + err.syscall + ': ' +
                    (err.path ? colors.blue(colors.underline((0, path_1.relative)(process.cwd(), err.path))) + ': ' : '') +
                    err.message.replace(err.code + ': ', '')
                        .replace(', ' + err.syscall + " '" + err.path + "'", '') + '.\n');
                electron_1.app.exit((err.errno ?? 0) * (-1));
            });
        };
    }
}
const singleInstance = electron_1.app.requestSingleInstanceLock();
let mainWindow;
let l10nStrings, updateInterval;
function main() {
    if (overwriteMain) {
        overwriteMain();
    }
    else {
        l10nStrings = (new l10n_1.default()).client;
        (0, update_1.checkVersion)(updateInterval);
        updateInterval = setInterval(function () { (0, update_1.checkVersion)(updateInterval); }, 1800000);
        mainWindow = (0, main_1.default)(startHidden, l10nStrings);
        (0, about_1.default)(l10nStrings);
    }
}
if (!singleInstance && !overwriteMain) {
    electron_1.app.on('ready', () => {
        console.log((new l10n_1.default()).client.misc.singleInstance);
        electron_1.app.quit();
    });
}
else {
    electron_1.app.on('second-instance', () => {
        if (mainWindow) {
            if (!mainWindow.isVisible())
                mainWindow.show();
            if (mainWindow.isMinimized())
                mainWindow.restore();
            mainWindow.focus();
        }
    });
    electron_1.app.on('ready', main);
    electron_1.app.on('activate', () => {
        if (electron_1.BrowserWindow.getAllWindows().length === 0)
            main();
    });
}
electron_1.app.on('window-all-closed', () => {
    if (process.platform !== 'darwin') {
        electron_1.app.quit();
    }
});
electron_1.app.on('web-contents-created', (_event, webContents) => {
    webContents.on('will-navigate', (event, url) => {
        const originUrl = webContents.getURL();
        if ((new URL(originUrl)).origin !== (new URL(url)).origin)
            event.preventDefault();
    });
    webContents.setWindowOpenHandler((details) => {
        const config = new config_1.AppConfig().get();
        if (!electron_1.app.isReady())
            return { action: 'deny' };
        const openUrl = new URL(details.url);
        const sameOrigin = new URL(webContents.getURL()).origin === openUrl.origin;
        let allowedProtocol = false;
        if (openUrl.protocol.match(global_1.trustedProtocolRegExp))
            allowedProtocol = true;
        if (allowedProtocol && !sameOrigin && config.redirectionWarning || !(new URL(webContents.getURL()).origin === global_1.knownIstancesList[config.currentInstance][1].origin)) {
            const window = electron_1.BrowserWindow.fromWebContents(webContents);
            const strings = (new l10n_1.default).client.dialog;
            const options = {
                type: 'warning',
                title: strings.common.warning + ': ' + strings.externalApp.title,
                message: strings.externalApp.message,
                buttons: [strings.common.yes, strings.common.no],
                defaultId: 1,
                cancelId: 1,
                detail: strings.common.source + ':\n' + details.url,
                textWidth: 320,
                normalizeAccessKeys: true
            };
            let result;
            if (window)
                result = electron_1.dialog.showMessageBoxSync(window, options);
            else
                result = electron_1.dialog.showMessageBoxSync(options);
            if (result === 1)
                return { action: 'deny' };
        }
        if (allowedProtocol)
            electron_1.shell.openExternal(details.url);
        return { action: 'deny' };
    });
});
