"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.loadChromeAddons = exports.loadNodeAddons = void 0;
const electron_1 = require("electron");
const fs = require("fs");
const path = require("path");
const l10n_1 = require("../../modules/l10n");
async function loadNodeAddons(window) {
    const strings = (new l10n_1.default()).client;
    const files = electron_1.dialog.showOpenDialogSync({
        title: strings.menubar.file.addon.loadNode,
        filters: [
            { name: strings.dialog.mod.nodeExt, extensions: ["asar"] }
        ]
    });
    console.log(files);
    if (files === undefined)
        return;
    for (const file of files) {
        const modJson = JSON.parse(fs.readFileSync(file + "/package.json", 'utf-8'));
        if (modJson === undefined)
            return;
        const modInfo = {
            name: modJson.productName || modJson.name,
            icon: path.join(file + '/' + modJson.webcord.icon),
            css: path.join(file + '/' + modJson.webcord.css),
            preload: path.join(file + '/' + modJson.webcord.preload)
        };
        console.log('CSS: ' + fs.existsSync(modInfo.css));
        console.log('Preload: ' + fs.existsSync(modInfo.preload));
        if (!fs.existsSync(modInfo.preload) && !fs.existsSync(modInfo.css)) {
            console.error("Failed on loading extension!");
            return;
        }
        if (modInfo.name)
            electron_1.app.setName(electron_1.app.getName() + ' (' + modInfo.name + ')');
        if (fs.existsSync(modInfo.icon))
            window.setIcon(modInfo.icon);
        if (fs.existsSync(modInfo.css)) {
            window.webContents.insertCSS(fs.readFileSync(modInfo.css, 'utf-8'));
            fs.readFileSync(modInfo.css, 'utf-8');
        }
    }
}
exports.loadNodeAddons = loadNodeAddons;
async function loadChromeAddons(window) {
    const strings = (new l10n_1.default()).client;
    const session = window.webContents.session;
    const files = electron_1.dialog.showOpenDialogSync({
        title: strings.menubar.file.addon.loadChrome,
        filters: [
            { name: strings.dialog.mod.crx, extensions: ["crx"] }
        ]
    });
    if (files === undefined)
        return;
    for (const file of files)
        session.loadExtension(file);
}
exports.loadChromeAddons = loadChromeAddons;
