"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.bar = exports.tray = exports.context = void 0;
const electron_1 = require("electron");
const client_1 = require("./client");
const config_1 = require("./config");
const appConfig = new config_1.AppConfig();
const addons_1 = require("./addons");
const electron_fetch_1 = require("electron-fetch");
const os = require("os");
const events_1 = require("events");
const bug_1 = require("../../modules/bug");
const l10n_1 = require("../../modules/l10n");
const settings_1 = require("../windows/settings");
const docs_1 = require("../windows/docs");
const sideBar = new events_1.EventEmitter();
const devel = (0, client_1.getBuildInfo)().type === 'devel';
sideBar.on('hide', async (contents) => {
    const cssKey = await contents.insertCSS(".sidebar-2K8pFh{ width: 0px !important; }");
    sideBar.once('show', () => {
        contents.removeInsertedCSS(cssKey);
    });
});
let wantQuit = false;
function context(windowName) {
    const strings = (new l10n_1.default()).client;
    windowName.webContents.on('context-menu', (event, params) => {
        const cmenu = [
            { type: 'separator' },
            { label: strings.context.cut, role: 'cut', enabled: params.editFlags.canCut },
            { label: strings.context.copy, role: 'copy', enabled: params.editFlags.canCopy },
            { label: strings.context.paste, role: 'paste', enabled: params.editFlags.canPaste },
            { type: 'separator' }
        ];
        let position = 0;
        for (const suggestion of params.dictionarySuggestions) {
            cmenu.splice(++position, 0, {
                label: suggestion,
                click: () => windowName.webContents.replaceMisspelling(suggestion)
            });
        }
        if (params.misspelledWord) {
            cmenu.splice(++position, 0, { type: 'separator' });
            cmenu.splice(++position, 0, {
                label: strings.context.dictionaryAdd,
                click: () => windowName.webContents.session.addWordToSpellCheckerDictionary(params.misspelledWord)
            });
            cmenu.splice(++position, 0, { type: 'separator' });
        }
        if (params.linkURL) {
            cmenu.push({
                label: strings.context.copyURL,
                click: () => electron_1.clipboard.writeText(params.linkURL)
            });
            if (params.linkText)
                cmenu.push({
                    label: strings.context.copyURLText,
                    click: () => electron_1.clipboard.writeText(params.linkText)
                });
            cmenu.push({ type: 'separator' });
        }
        if (devel || appConfig.get().devel) {
            cmenu.push({
                label: strings.context.inspectElement,
                click: () => windowName.webContents.inspectElement(params.x, params.y)
            });
            cmenu.push({ type: 'separator' });
        }
        electron_1.Menu.buildFromTemplate(cmenu).popup({
            window: windowName,
            x: params.x,
            y: params.y
        });
    });
}
exports.context = context;
let funMode = false;
const today = new Date();
if (os.userInfo().username == 'pi' && today.getDate() == 14 && today.getMonth() == 2) {
    funMode = true;
}
async function tray(windowName) {
    const strings = (new l10n_1.default()).client;
    const tray = new electron_1.Tray(client_1.appInfo.trayIcon);
    let icon;
    if (funMode) {
        icon = electron_1.nativeImage.createFromBuffer(await (await (0, electron_fetch_1.default)('https://raw.githubusercontent.com/iiiypuk/rpi-icon/master/16.png')).buffer());
    }
    else {
        icon = electron_1.nativeImage.createFromPath(client_1.appInfo.icon);
    }
    function toogleVisibility() {
        if (windowName.isVisible() && windowName.isFocused()) {
            windowName.hide();
        }
        else if (!windowName.isVisible()) {
            windowName.show();
        }
        else {
            windowName.focus();
        }
    }
    const contextMenu = electron_1.Menu.buildFromTemplate([
        {
            label: electron_1.app.getName(),
            enabled: false,
            icon,
        },
        { type: 'separator' },
        {
            label: strings.help.about,
            role: 'about',
            click: electron_1.app.showAboutPanel
        },
        {
            label: strings.help.docs,
            click: () => (0, docs_1.default)(windowName)
        },
        {
            label: strings.help.bugs,
            click: () => (0, bug_1.createGithubIssue)()
        },
        { type: 'separator' },
        {
            label: strings.tray.toggle,
            click: toogleVisibility
        },
        {
            label: strings.tray.quit,
            click: function () {
                wantQuit = true;
                electron_1.app.quit();
            }
        }
    ]);
    tray.setContextMenu(contextMenu);
    tray.setToolTip(electron_1.app.getName());
    tray.on("click", toogleVisibility);
    windowName.on('close', (event) => {
        if (!wantQuit) {
            event.preventDefault();
            windowName.hide();
        }
    });
    return tray;
}
exports.tray = tray;
function bar(repoLink, mainWindow) {
    const strings = (new l10n_1.default()).client;
    const webLink = repoLink.substring(repoLink.indexOf("+") + 1);
    const menu = electron_1.Menu.buildFromTemplate([
        {
            label: strings.menubar.file.groupName, submenu: [
                {
                    label: strings.settings.title,
                    click: () => (0, settings_1.default)(mainWindow)
                },
                {
                    label: strings.menubar.file.addon.groupName, visible: devel || appConfig.get().devel, submenu: [
                        {
                            label: strings.menubar.file.addon.loadNode,
                            enabled: devel,
                            click: () => (0, addons_1.loadNodeAddons)(mainWindow)
                        },
                        {
                            label: strings.menubar.file.addon.loadChrome,
                            enabled: devel,
                            click: () => (0, addons_1.loadChromeAddons)(mainWindow)
                        }
                    ]
                },
                { type: 'separator' },
                {
                    label: strings.menubar.file.relaunch,
                    accelerator: 'CmdOrCtrl+Alt+R',
                    click: () => {
                        wantQuit = true;
                        const newArgs = [];
                        for (const arg of process.argv) {
                            let willBreak = false;
                            for (const sw of ['start-minimized', 'm'])
                                if (arg.includes('-') && arg.endsWith(sw)) {
                                    willBreak = true;
                                    break;
                                }
                            if (willBreak)
                                break;
                            newArgs.push(arg);
                        }
                        newArgs.shift();
                        electron_1.app.relaunch({
                            args: newArgs,
                        });
                        electron_1.app.quit();
                    }
                },
                {
                    label: strings.menubar.file.quit,
                    accelerator: 'CmdOrCtrl+Q',
                    click: () => {
                        wantQuit = true;
                        electron_1.app.quit();
                    }
                }
            ]
        },
        { role: 'editMenu', label: strings.menubar.edit.groupName, submenu: [
                { label: strings.menubar.edit.undo, role: 'undo' },
                { label: strings.menubar.edit.redo, role: 'redo' },
                { type: 'separator' },
                { label: strings.context.cut, role: 'cut' },
                { label: strings.context.copy, role: 'copy' },
                { label: strings.context.paste, role: 'paste' }
            ] },
        {
            label: strings.menubar.view.groupName, submenu: [
                { label: strings.menubar.view.reload, role: 'reload' },
                { label: strings.menubar.view.forceReload, role: 'forceReload' },
                { type: 'separator' },
                {
                    label: strings.menubar.view.devTools,
                    id: 'devTools',
                    role: 'toggleDevTools',
                    enabled: devel || appConfig.get().devel
                },
                { type: 'separator' },
                { label: strings.menubar.view.resetZoom, role: 'resetZoom' },
                { label: strings.menubar.view.zoomIn, role: 'zoomIn' },
                { label: strings.menubar.view.zoomOut, role: 'zoomOut' },
                { type: 'separator' },
                { label: strings.menubar.view.fullScreen, role: 'togglefullscreen' }
            ]
        },
        {
            label: strings.menubar.window.groupName, submenu: [
                {
                    label: strings.menubar.window.mobileMode,
                    type: 'checkbox',
                    accelerator: 'CmdOrCtrl+Alt+M',
                    checked: false,
                    click: async () => {
                        if ((sideBar.listenerCount('show') + sideBar.listenerCount('hide')) > 1) {
                            sideBar.emit('show');
                        }
                        else {
                            sideBar.emit('hide', mainWindow.webContents);
                        }
                    }
                }
            ]
        },
        {
            label: strings.help.groupName, role: 'help', submenu: [
                { label: strings.help.about, role: 'about', click: () => electron_1.app.showAboutPanel() },
                { label: strings.help.repo, click: () => electron_1.shell.openExternal(webLink) },
                { label: strings.help.docs, click: () => (0, docs_1.default)(mainWindow) },
                { label: strings.help.bugs, click: () => (0, bug_1.createGithubIssue)() }
            ]
        }
    ]);
    electron_1.Menu.setApplicationMenu(menu);
    return menu;
}
exports.bar = bar;
