"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const copyYear = "2020-2021";
const global_1 = require("../../global");
const fs_1 = require("fs");
const client_1 = require("../modules/client");
const electron_1 = require("electron");
let appContributors = [global_1.packageJson.author.name];
if (process.platform === "linux") {
    if (global_1.packageJson.author.url)
        appContributors = ['<a href="' + global_1.packageJson.author.url + '">' + global_1.packageJson.author.name + '</a>'];
    else if (global_1.packageJson.author.email)
        appContributors = ['<a href="mailto:' + global_1.packageJson.author.email + '">' + global_1.packageJson.author.name + '</a>'];
}
if (global_1.packageJson.contributors !== undefined && global_1.packageJson.contributors.length > 0) {
    for (let n = 0; n < global_1.packageJson.contributors.length; n++) {
        if (global_1.packageJson.contributors[n].name) {
            if (process.platform == "linux") {
                const { name, email, url } = global_1.packageJson.contributors[n];
                let linkTag = "", linkTagClose = "";
                if (url) {
                    linkTag = '<a href="' + url + '">';
                }
                else if (email) {
                    linkTag = '<a href="mailto:' + email + '">';
                }
                if (linkTag !== "")
                    linkTagClose = "</a>";
                appContributors.push(linkTag + name + linkTagClose);
            }
            else {
                appContributors.push(global_1.packageJson.contributors[n].name);
            }
        }
        else {
            appContributors.push(global_1.packageJson.contributors[n]);
        }
    }
}
const stringContributors = appContributors.join(', ');
function setAboutPanel(l10nStrings) {
    let iconPath = client_1.appInfo.icon.replace(/\.asar(\\|\/)/, '.asar.unpacked$1');
    let commit = (0, client_1.getBuildInfo)().commit?.substring(0, 7) ?? '';
    if (commit !== '')
        commit = '-' + commit;
    if (process.platform === 'linux' && !(0, fs_1.existsSync)(client_1.appInfo.icon)) {
        iconPath = '/usr/share/icons/hicolor/512x512/apps/' + global_1.packageJson.name + '.png';
    }
    const aboutVersions = "Electron: " + process.versions.electron + "    Node: " + process.versions.node + "    Chromium: " + process.versions.chrome;
    electron_1.app.setAboutPanelOptions({
        applicationName: electron_1.app.getName(),
        applicationVersion: 'v' + electron_1.app.getVersion() + commit + ' (' + (0, client_1.getBuildInfo)().type + ')',
        authors: appContributors,
        website: global_1.packageJson.repository.url.slice(4),
        credits: l10nStrings.help.contributors + ' ' + stringContributors,
        copyright: 'MIT License\n' + 'Copyright © ' + copyYear + ' ' + global_1.packageJson.author.name + '\n\n' + l10nStrings.help.credits + '\n\n' + aboutVersions,
        iconPath: iconPath
    });
}
exports.default = setAboutPanel;
