"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const electron_1 = require("electron");
const fs_1 = require("fs");
const path_1 = require("path");
const client_1 = require("../modules/client");
const l10n_1 = require("../../modules/l10n");
function handleEvents(docsWindow) {
    let readmeFile = 'docs/Readme.md';
    if ((0, fs_1.existsSync)((0, path_1.resolve)(electron_1.app.getAppPath(), 'docs', electron_1.app.getLocale(), 'Readme.md')))
        readmeFile = 'docs/' + electron_1.app.getLocale() + '/Readme.md';
    electron_1.ipcMain.once('documentation-load', (event) => {
        electron_1.ipcMain.once('documentation-load', () => {
            if (!docsWindow.isDestroyed()) {
                docsWindow.show();
            }
        });
        event.reply('documentation-load', (0, path_1.resolve)(electron_1.app.getAppPath(), readmeFile));
    });
}
function loadDocsWindow(parent) {
    const strings = (new l10n_1.default()).client;
    const docsWindow = new electron_1.BrowserWindow({
        title: electron_1.app.getName() + ' – ' + strings.help.docs,
        show: false,
        parent: parent,
        minWidth: client_1.appInfo.minWinWidth,
        minHeight: client_1.appInfo.minWinHeight,
        width: 800,
        height: 720,
        webPreferences: {
            session: electron_1.session.fromPartition("temp:docs"),
            preload: (0, path_1.resolve)(electron_1.app.getAppPath(), 'sources/app/renderer/preload/docs.js'),
            defaultFontFamily: {
                standard: 'Arial'
            }
        }
    });
    docsWindow.loadFile((0, path_1.resolve)(electron_1.app.getAppPath(), 'sources/assets/web/html/docs.html'));
    handleEvents(docsWindow);
    docsWindow.webContents.on('did-start-loading', () => handleEvents(docsWindow));
    docsWindow.webContents.session.setPermissionCheckHandler(() => false);
    docsWindow.webContents.session.setPermissionRequestHandler((_webContents, _permission, callback) => {
        callback(false);
    });
    docsWindow.webContents.session.setDevicePermissionHandler(() => false);
    docsWindow.setAutoHideMenuBar(true);
    docsWindow.setMenuBarVisibility(false);
    if ((0, client_1.getBuildInfo)().type === 'release')
        docsWindow.removeMenu();
    return docsWindow;
}
exports.default = loadDocsWindow;
