"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const electron_1 = require("electron");
const fs_1 = require("fs");
const path = require("path");
function renderCapturerContainer(sources) {
    const container = document.createElement('div');
    container.setAttribute('class', 'capturer-selection');
    const style = document.createElement('style');
    style.innerHTML = (0, fs_1.readFileSync)(path.resolve(__dirname, '../../../assets/web/css/capturer.css')).toString();
    container.appendChild(style);
    const scroller = document.createElement('div');
    scroller.className = "capturer-scroller";
    const list = document.createElement('ul');
    list.className = "capturer-list";
    for (const source of sources) {
        const item = document.createElement('li');
        item.className = "capturer-item";
        const button = document.createElement('button');
        button.className = "capturer-button";
        button.setAttribute('data-id', source.id);
        button.setAttribute('title', source.name);
        const thumbnail = document.createElement('img');
        thumbnail.className = "capturer-thumbnail";
        thumbnail.src = source.thumbnail.toDataURL();
        button.appendChild(thumbnail);
        const labelContainer = document.createElement('div');
        labelContainer.className = "capturer-label-container";
        if (source.appIcon) {
            const icon = document.createElement('img');
            icon.className = "capturer-label-icon";
            icon.src = source.appIcon.toDataURL();
            labelContainer.appendChild(icon);
        }
        const label = document.createElement('span');
        label.className = "capturer-label";
        label.innerText = source.name;
        labelContainer.appendChild(label);
        button.appendChild(labelContainer);
        item.appendChild(button);
        list.appendChild(item);
    }
    scroller.appendChild(list);
    const buttonClose = document.createElement('button');
    buttonClose.className = "capturer-close";
    buttonClose.innerText = "✕";
    scroller.appendChild(buttonClose);
    container.appendChild(scroller);
    document.body.appendChild(container);
    return container;
}
function desktopCapturerPicker() {
    return new Promise(async (resolve, reject) => {
        try {
            const sources = await electron_1.desktopCapturer.getSources({ types: ['screen', 'window'], fetchWindowIcons: true });
            const container = renderCapturerContainer(sources);
            for (const button of document.querySelectorAll('.capturer-button'))
                button.addEventListener('click', () => {
                    try {
                        const id = button.getAttribute('data-id');
                        const source = sources.find(source => source.id === id);
                        if (!source) {
                            throw new Error('Source with id: "' + id + '" does not exist!');
                        }
                        const constrains = {
                            audio: false,
                            video: {
                                mandatory: {
                                    chromeMediaSource: 'desktop',
                                    chromeMediaSourceId: source.id
                                }
                            }
                        };
                        resolve(constrains);
                        container.remove();
                    }
                    catch (err) {
                        console.error('[ERROR] Failed to select desktop capture source: "' + err + '"!');
                        reject(err);
                    }
                });
            document.querySelector('.capturer-close')
                ?.addEventListener('click', () => container.remove());
        }
        catch (err) {
            console.error('[ERROR] Failed to display desktop capture sources: "' + err + '"!');
            reject(err);
        }
    });
}
exports.default = desktopCapturerPicker;
